@@ -10,6 +10,8 @@ class Product:
     price_max: float
     in_stock: bool
     stock: int
+    ship_day_min: int
+    ship_day_max: int
     ship: str
     delivery: str
     material: str
