@@ -1,7 +1,9 @@
-import numpy
 import re
 from typing import Union
 
+import js2py
+import js2py.internals.simplex
+import numpy
 import pandas
 import parsel
 
@@ -49,6 +51,7 @@ def parse(html: str, p: Product):
     parse_price(p, selector=sel)
     parse_in_stock(p, selector=sel)
     parse_stock(p, selector=sel)
+    parse_ship_day(p, selector=sel)
     parse_ship(p, selector=sel)
     parse_delivery(p, selector=sel)
     parse_material(p, selector=sel)
@@ -186,6 +189,16 @@ def parse_stock(p: Product, selector: parsel.Selector = None):
     p.stock = parse_number(stock)
 
 
+def parse_ship_day(p: Product, selector: parsel.Selector = None):
+    ship_day = selector.xpath("//div[@id='availability']/span/text()").re(r"Usually ships within (\d+) to (\d+) days.")
+    if len(ship_day) < 2:
+        p.ship_day_min = None
+        p.ship_day_max = None
+    else:
+        p.ship_day_min = int(ship_day[0])
+        p.ship_day_max = int(ship_day[1])
+
+
 def parse_ship(p: Product, selector: parsel.Selector = None):
     def s1() -> str:
         table = selector.xpath("//table[@id='tabular-buybox-container']").get()
@@ -302,6 +315,42 @@ def parse_color(p: Product, selector: parsel.Selector = None):
 
 
 def parse_variation(p: Product, selector: parsel.Selector = None):
-    p.variation_values = None
-    p.selected_variations = None
-    p.asin_variation_values = None
+    variation = selector.xpath(
+        "normalize-space(//script[contains(text(), 'twister-js-init-dpx-data')]/text())"
+    ).re_first("dataToReturn = {.+};")
+    if variation is None:
+        p.variation_values = None
+        p.selected_variations = None
+        p.asin_variation_values = None
+        return
+
+    try:
+        variation = js2py.eval_js(variation)
+        labels = variation.variationDisplayLabels.to_dict()
+        values = variation.variationValues.to_dict()
+        selected = variation.selected_variations.to_dict()
+        variations = variation.asinVariationValues.to_dict()
+    except (js2py.internals.simplex.JsException, AttributeError):
+        p.variation_values = None
+        p.selected_variations = None
+        p.asin_variation_values = None
+        return
+
+    def change_key(d: dict):
+        return {labels[k]: v for k, v in d.items() if k in labels}
+
+    def change_variations(vars_d: dict) -> list:
+        vars_l = list()
+        for _, var in vars_d.items():
+            var_change = dict()
+            for k, v in var.items():
+                if k in labels and k in values:
+                    var_change[labels[k]] = values[k][int(v)]
+                else:
+                    var_change[k] = v
+            vars_l.append(var_change)
+        return vars_l
+
+    p.variation_values = change_key(values)
+    p.selected_variations = change_key(selected)
+    p.asin_variation_values = change_variations(variations)
